import { useRequestEvent } from "#imports";
export const useGithub = () => {
  const fetchRepository = (query) => {
    const url = `/api/_github/repository/${encodeParams(query)}.json`;
    process.server && addPrerenderPath(url);
    return $fetch(url, { responseType: "json" });
  };
  const fetchRelease = (query) => {
    const url = `/api/_github/releases/${encodeParams(query)}.json`;
    process.server && addPrerenderPath(url);
    return $fetch(url, { responseType: "json" });
  };
  const fetchLastRelease = (query) => {
    const url = `/api/_github/releases/${encodeParams({ ...query, last: true })}.json`;
    process.server && addPrerenderPath(url);
    return $fetch(url, { responseType: "json" });
  };
  const fetchReleases = (query) => {
    const url = `/api/_github/releases/${encodeParams(query)}.json`;
    process.server && addPrerenderPath(url);
    return $fetch(url, { responseType: "json" });
  };
  const fetchContributors = (query) => {
    const url = `/api/_github/contributors/${encodeParams(query)}.json`;
    process.server && addPrerenderPath(url);
    return $fetch(url, { responseType: "json" });
  };
  const fetchFileContributors = (query) => {
    const url = `/api/_github/contributors/file/${encodeParams(query)}.json`;
    process.server && addPrerenderPath(url);
    return $fetch(url, { responseType: "json" });
  };
  const fetchReadme = (query) => {
    const url = `/api/_github/readme/${encodeParams(query)}.json`;
    process.server && addPrerenderPath(url);
    return $fetch(url, { responseType: "json" });
  };
  return {
    fetchRepository,
    fetchReleases,
    fetchRelease,
    fetchLastRelease,
    fetchContributors,
    fetchFileContributors,
    fetchReadme
  };
};
function encodeParams(params) {
  return Object.entries(params).map(([key, value]) => `${key}_${String(value)}`).join(":");
}
function addPrerenderPath(path) {
  const event = useRequestEvent();
  event.res.setHeader(
    "x-nitro-prerender",
    [
      event.res.getHeader("x-nitro-prerender"),
      path
    ].filter(Boolean).join(",")
  );
}
